@@ -5,7 +5,8 @@ def media(request):
     """Adds media-related variables to the `context`."""
     return {
         'PAGES_MEDIA_URL': settings.PAGES_MEDIA_URL,
-        'PAGE_USE_SITE_ID': settings.PAGE_USE_SITE_ID
+        'PAGE_USE_SITE_ID': settings.PAGE_USE_SITE_ID,
+        'PAGE_HIDE_SITES': settings.PAGE_HIDE_SITES,
     }
 
 def pages_navigation(request):
@@ -15,3 +16,4 @@ def pages_navigation(request):
         'pages_navigation': pages,
         'current_page':None
     }
+  
