@@ -40,8 +40,8 @@ class FunctionnalTestCase(TestCase):
 
     def test_delete_page(self):
         """Create a page, then delete it."""
-        c = self.get_admin_client()        
-        page_data = self.get_new_page_data()     
+        c = self.get_admin_client()
+        page_data = self.get_new_page_data()
         response = c.post('/admin/pages/page/add/', page_data)
         self.assertRedirects(response, '/admin/pages/page/')
         slug_content = Content.objects.get_content_slug_by_slug(
@@ -56,7 +56,7 @@ class FunctionnalTestCase(TestCase):
         )
         assert(slug_content is None)
         self.assertEqual(Page.objects.count(), pageCount - 1)
-        
+
     def test_slug_collision(self):
         """Test a slug collision."""
         setattr(settings, "PAGE_UNIQUE_SLUG_REQUIRED", True)
@@ -132,7 +132,7 @@ class FunctionnalTestCase(TestCase):
         disable it"""
 
         from pages import settings as pages_settings
-        
+
         # it's not possible to enforce PAGE_USE_SITE_ID in the tests
         if not pages_settings.PAGE_USE_SITE_ID:
             #TODO: use unittest.skip skip when 2.7
@@ -244,14 +244,14 @@ class FunctionnalTestCase(TestCase):
         # header so I used django_language cookie instead
         c = self.get_admin_client()
         c.cookies["django_language"] = 'en-us'
-        response = c.get(self.get_page_url())
+        response = c.get(page.get_url_path())
         self.assertContains(response, 'english title')
         self.assertContains(response, 'lang="en-us"')
         self.assertNotContains(response, 'french title')
 
         c = self.get_admin_client()
         c.cookies["django_language"] = 'fr-ch'
-        response = c.get(self.get_page_url())
+        response = c.get(page.get_url_path())
         self.assertContains(response, 'french title')
         self.assertContains(response, 'lang="fr-ch"')
 
@@ -260,7 +260,7 @@ class FunctionnalTestCase(TestCase):
         # this should be mapped to the fr-ch content
         c = self.get_admin_client()
         c.cookies["django_language"] = 'fr-fr'
-        response = c.get(self.get_page_url())
+        response = c.get(page.get_url_path())
         self.assertContains(response, 'french title')
         self.assertContains(response, 'lang="fr-ch"')
 
@@ -283,7 +283,7 @@ class FunctionnalTestCase(TestCase):
         self.assertEqual(Content.objects.get_content(page, 'en-us', 'body'),
             'changed body 2')
 
-        response = c.get(self.get_page_url())
+        response = c.get(page.get_url_path())
         self.assertContains(response, 'changed body 2', 1)
 
         setattr(settings, "PAGE_CONTENT_REVISION", False)
@@ -342,10 +342,10 @@ class FunctionnalTestCase(TestCase):
 
         # finaly test that we can get every page according the path
         response = c.get(self.get_page_url('same-slug'))
-        self.assertContains(response, "parent title", 2)
+        self.assertContains(response, "parent title", 3)
 
         response = c.get(self.get_page_url('same-slug/same-slug'))
-        self.assertContains(response, "children title", 2)
+        self.assertContains(response, "children title", 3)
 
 
     def test_page_admin_view(self):
@@ -419,7 +419,7 @@ class FunctionnalTestCase(TestCase):
 
         # for the download page, the slug is canonical
         response = c.get(self.get_page_url('downloads-page/'))
-        self.assertContains(response, "downloads-page-title", 2)
+        self.assertContains(response, "downloads-page-title", 3)
 
         # calling via its alias must cause redirect
         response = c.get(self.get_page_url('index.php')+'?page=downloads')
@@ -535,6 +535,7 @@ class FunctionnalTestCase(TestCase):
         from pages.views import details
         from pages.utils import get_request_mock
         request = get_request_mock()
+        request.path = page1.get_url_path()
         context = details(request, only_context=True)
         self.assertEqual(context['current_page'], page1)
 
@@ -736,7 +737,7 @@ class FunctionnalTestCase(TestCase):
             label='test')
         page.delegate_to = 'test'
         page.save()
-        
+
         response = c.get('/pages/delegate')
         self.assertEqual(response.status_code, 200)
 
@@ -758,7 +759,30 @@ class FunctionnalTestCase(TestCase):
             Content.objects.get_content(page, 'en-us', 'untrans'),
             unstranslated_string
         )
-        
+
         page_data['untrans'] = ''
         response = c.get('/admin/pages/page/%d/?language=fr-ch' % page.id)
         self.assertContains(response, unstranslated_string)
+
+    def test_root_page(self):
+        """Test that the root page doesn't trigger a 404."""
+        c = self.get_admin_client()
+        page1 = self.new_page(content={'slug':'this-is-not-a-404'})
+        self.assertEqual(Page.objects.count(), 1)
+        page = Page.objects.on_site()[0]
+        self.assertTrue(page.is_first_root())
+
+        response = c.get('/pages/')
+        self.assertEqual(response.status_code, 200)
+
+    def test_page_with_trailing_slash(self):
+        """
+        Test that a page is also available with and without a trailing slash.
+        """
+        c = self.get_admin_client()
+        page1 = self.new_page(content={'slug':'root'})
+        page2 = self.new_page(content={'slug':'other'})
+        response = c.get('/pages/other')
+        self.assertEqual(response.status_code, 200)
+        response = c.get('/pages/other/')
+        self.assertEqual(response.status_code, 200)
