@@ -5,9 +5,9 @@ from django.conf.urls.defaults import handler404, handler500
 from pages.views import details
 from pages import settings
 
+# Public pages
 urlpatterns = patterns('',
-    # Public pages
-    url(r'^$', details, name='pages-root'),
+    url(r'^/$', details, name='pages-root'),
 )
 
 if settings.PAGE_USE_LANGUAGE_PREFIX:
