@@ -1,3 +1,4 @@
+"""Django page CMS widget registry."""
 __all__ = ('register_widget',)
 from django.utils.translation import ugettext as _
 
@@ -17,14 +18,18 @@ class WidgetNotFound(Exception):
 registry = []
 
 def register_widget(widget):
-
+    """
+    Register the given widget as a candidate to use in placeholder.
+    """
     if widget in registry:
-        raise AlreadyRegistered(
+        raise WidgetAlreadyRegistered(
             _('The widget %s has already been registered.') % widget.__name__)
     registry.append(widget)
 
 def get_widget(name):
-
+    """
+    Give back a widget class according to his name.
+    """
     for widget in registry:
         if widget.__name__ == name:
             return widget
